<?php



require_once 'config.php';
require_once GREEN_ZONE_DIR . 'Utils/StringUtils.php';
require_once 'Classes/General/Date.php';


class MJD
{
  // PUBLIC

  public function __construct( $mjd = '' )
  {
    $this->day = '';
    $this->frac_day = '';
    $this->FromString( $mjd );
  }
  
  public function FromString( $mjd )
  {
    if( $mjd != '' )
    {
      $this->day = strword( $mjd, 0, '.' );
      $this->frac_day = strword( $mjd, 1, '.' );
    }
  }

  public function ToString()
  {
    return $this->day . '.' . $this->frac_day;
  }

  // From http://quasar.as.utexas.edu/BillInfo/JulianDatesG.html
  public function ToDate()
  {
    $jdval = floatval($this->ToString()) + 2400000.5;
    $z = $jdval + 0.5;
	
    $w = floor(($z - 1867216.25)/36524.25);
    $x = floor($w/4);
    $a = floor($z+1+$w-$x);
    $b = floor($a + 1524);
    $c = floor(($b-122.1)/365.25);
    $d = floor(365.25*$c);
    $e = floor(($b-$d)/30.6001);
    $f = floor(30.6001 * $e);
	
    $day = $b-$d-$f;
    $month = $e-1;
    if ($month > 12) {
      $month = $e - 13;
    }
	
    if ($month == 1 || $month == 2) {
      $year = $c - 4715;
    }
    else {
      $year = $c - 4716;
    }
    
    
    $gregorian = new Date( $day . '/' . $month . '/' . $year );
    
    return $gregorian;
  }
  
  public function FromDate( $gregorian )
  {
    $year = intval($gregorian->GetYear());
    $month = intval($gregorian->GetMonthOfYear());
    $day = intval($gregorian->GetDayOfMonth());
    
    if ($month == 1 || $month == 2) {
      $year = $year - 1;
      $month += 12;
    }
	
    $a = floor($year/100);
	
    $b = floor($a/4);
    $c = 2 - $a + $b;
    $e = floor(365.25 * ($year + 4716));
    $f = floor(30.6001 * ($month + 1));
    $jd = $c+$day+$e+$f - 1524.5;
	
    $this->FromString( $jd - 2400000.5);
  }

  // PRIVATE

  private $day;
  private $frac_day;
};


?>