<?php



require_once 'constants.php';
require_once 'File.php';
require_once 'Dir.php';


/**
 * This class represents an algorithm to take a cspr2 observation, which is a directory
 * containing several archive files, and combining them into a single observation file.
 * It calls psradd to perform the actual work of combining the files.
 *
 * Usage
 *  $src_dir = new Dir( 'path to cpsr2 data directory' );
 *  $dest_file = new File( 'target data dir', 'target filename' );
 *  $combiner = new CPSR2Combiner();
 *  $combiner->SetSrcDir( $src_dir );
 *  $combiner->SetDestFile( $dest_file );
 *  $combiner->Execute();
 **/

class CPSR2Combiner
{
  public __construct()
  {
    $this->src_dir = new Dir();
    $this->dest_file = new File();
  }

  public SetSrcDir( $s_src_dir ) { $this->src_dir = $s_src_dir; }
  public SetDestFile( $s_dest_file ) { $this->dest_file = $s_dest_file; }

  public Execute()
  {
    // Get a list of all the .cfb files from the src directory
    $src_files = $src_dir->ListFiles();
    $src_files_str = ' ';
    foreach( $src_files as $next_filename )
      $src_files_str .= $src_dir->GetPath() . '/' . $next_filename;

    $psradd_cmd = FIX_LD_LIB . PSRADD_CMD . ' -f ' . $dest_file->GetFullPath() . $src_files_str;
    $retval = '';
    $all_lines = Array();

    echo 'execing command ' . $psradd_cmd . ' <br> ';
    exec( $psradd_cmd, $all_lines, $retval );

    // TODO throw an exception if the psradd call failed or if the file wasn't created
    if( !$dest_file->Exists() )
    {
      echo 'failed to psradd files together <br>';
      exit;
    }
  }

  private $src_dir;
  private $dest_file;
};


?>