<?php



require_once GREEN_ZONE_DIR . 'Forms/GZ_BaseForm.php';
require_once GREEN_ZONE_DIR . 'Forms/GZ_Paginator.php';
require_once 'Forms/QueryFormParameters.php';
require_once 'Forms/ObservationsTable.php';
require_once 'Classes/Model/Observation.php';
require_once 'Classes/Queries/ConeQuery.php';
require_once 'Classes/Queries/CalQuery.php';
require_once 'Classes/General/Pair.php';
require_once 'Classes/Pulsar/PulsarCatalog.php';
require_once 'Classes/General/UserData.php';



/**
 * @class QueryResultsForm
 * 
 * This form uses a GZ_Table to display the results from the last query performd.
 * It also presents some controls and responds to the following user actions
 * - ConeQuery (Perform the actual query using the posted form data)
 * - NewQuery  (Return to the query form)
 * - ShowCart  (Switch to the cart form)
 * - AddToCart (Add all the selected observations to the cart session data.
 **/

class QueryResultsForm extends GZ_BaseForm
{
  // PUBLIC

  public function __construct( $set_gz )
  {
    global $_SESSION;
    
    parent::__construct( $set_gz );

    $this->last_result_set = Array();
    $this->last_query = null;
    
    isset( $_SESSION['last_results'] ) ?
	$this->last_result_set = $_SESSION['last_results'] : $this->last_result_set = Array();
    
    isset( $_SESSION['cart_contents'] ) ?
	$this->cart_contents = $_SESSION['cart_contents'] : $this->cart_contents = Array();
    
    $this->SetupObservationsTable();
    
    $this->SetupPaginator();
    
    $this->download_size = 0.0;
    
    $this->date_range_adjusted = false;
  }
  
  public function Display()
  {
    $smarty = $this->gz->CreateSmarty();
    $this->gz->smarty_assign( $smarty, 'cart_size', count( $this->cart_contents ) );
    $this->gz->smarty_assign( $smarty, 'download_size', $this->download_size );
    
    $adjusted_from_date = null;
    $adjusted_to_date = null;
    if( $this->date_range_adjusted )
    {
      $adjusted_from_date = $this->parameters->GetDateRange()->GetFromDate()->ToDMYString();
      $adjusted_to_date = $this->parameters->GetDateRange()->GetToDate()->ToDMYString();
    }
    $this->gz->smarty_assign( $smarty, 'adjusted_from_date', $adjusted_from_date );
    $this->gz->smarty_assign( $smarty, 'adjusted_to_date', $adjusted_to_date );
    
    $smarty->display( 'QueryResultsFormHeader.tpl' );

    if( $this->last_result_set != '' )
    {
      $this->paginator->Display();
      $this->obs_table->Display();
    }
    
    $smarty->display( 'QueryResultsFormFooter.tpl' );
  }

  public function ReadForm()
  {
    $this->obs_table->ReadForm();
    $this->paginator->ReadForm();
  }
  
  public function ProcessActions()
  {
    $next_form = '';
    
    $this->obs_table->SetData( $this->last_result_set );
    

    
    if( $this->ActionIs( 'ConeQuery' ) )
    {
      $this->ProcessConeQuery();
      $this->obs_table->SetData( $this->last_result_set );
      $this->paginator->ProcessActions();
    }
    else if( $this->ActionIs( 'NewQuery' ) )
      $next_form = 'QueryForm';
    else if( $this->ActionIs( 'ShowCart' ) )
      $next_form = 'CartForm';
    else if( $this->ActionIs( 'PerformAction' ) )
    {
      $action = $this->GetPostString( 'Action' );
      if( $action == 'AddToCart' )
        $this->AddToCart();
      else if( $action == 'ViewProfiles' )
        $this->ViewProfiles();
      else if( $action == 'ViewProfilesAndCals' )
        $this->ViewProfilesAndCals();
    }

    $this->obs_table->ProcessActions();
    $this->paginator->ProcessActions();

    
    return $next_form;
  }

  // PRIVATE

  private $last_result_set;
  private $query_failure_msg;
  private $parameters;
  private $cart_contents;
  private $obs_table;
  private $pager;
  private $download_size;
  private $date_range_adjusted;
  
  
  private function SetupObservationsTable()
  {
    $this->obs_table = new ObservationsTable( $this->gz, 'tabQueryResults' );
    
    $this->obs_table->SetColumnHeadings( Array( 'distance', 'filename', 'src_name', 'project_id', 
					 'rajd', 'decjd', 'data_type', 'obsfreq', 'bw',
					 'scanlen', 'date', 'ut', 'mjd' ) );
    
    $this->obs_table->SetData( $this->last_result_set );
  }
  
  private function SetupPaginator()
  {
    $table_pager = new GZ_Pager();
    $table_pager->SetTarget( $this->obs_table );
    $table_pager->SetItemsPerPage( 15 );
    
    $this->paginator = new GZ_Paginator( $this->gz, 'QueryResultsFormPaginator' );
    $this->paginator->AddPager( $table_pager );
  }

  private function PerformQuery()
  {
    // If we were given a pulsar name, set the rajd and decjd to that pulsar
	
    $query = new ConeQuery();
    if( $this->parameters->GetPulsarName() != '' )
    {
      $catalog = new PulsarCatalog();
      $coords = $catalog->GetCoordsForPulsar( $this->parameters->GetPulsarName() );
      $this->parameters->SetCoordinates( $coords );
    }
    
    // If the user is anonymous, drop the to_limit on the date range down by 18 months
    $this->AdjustDateRange();
    
    
    $query->SetParameters( $this->parameters );
    $query->Execute( $this->gz );
    $this->last_result_set = $query->GetResults();
  }
  
  private function ProcessConeQuery()
  {
    global $_SESSION;
    
    $this->parameters = new QueryFormParameters();
    $this->parameters->ReadForm( $this->gz->_POST );

    $pulsar_name = $this->parameters->GetPulsarName();
    if( $pulsar_name != '' )
    {
      $catalog = new PulsarCatalog();
      $coordinates = $catalog->GetCoordsForPulsar( $pulsar_name );
      $this->parameters->SetCoordinates( $coordinates );
    }

    $this->PerformQuery();
    
    // if we have a time window from which we want cals
    // for each observation
    //    calculate the time window as start and end mjds
    //    create a cal query
    //    give it the start and end mjd times
    //    perform the cal query
    //    if we have any cal results
    //      add those cal results to the observation
        
    if( $this->parameters->GetCalsWindow() != null )
    {
      for( $obs = 0; $obs < count( $this->last_result_set ); $obs ++ )
      {
        $obs_time = $this->last_result_set[$obs]->GetMJD();
        // determine a min as a fraction of a day
        $half_min = 0.5 / (24.0 * 60.0);
        
        $min_mjd = new MJD();
        $min_mjd->FromString( $obs_time->ToString() - $this->parameters->GetCalsWindow() * $half_min );
        
        $max_mjd = new MJD();
        $max_mjd->FromString( $obs_time->ToString() + $this->parameters->GetCalsWindow() * $half_min );
        
        $cal_query = new CalQuery();
        $cal_query->SetStartTime( $min_mjd );
        $cal_query->SetEndTime( $max_mjd );
        $cal_query->Execute( $this->gz );
        $cals = $cal_query->GetCalibrations();
        
        $this->last_result_set[$obs]->SetCalibrations( $cals );
      }
    }
    else
    {
      echo 'we dont want any cals <br>';
    }
      
    $_SESSION['last_query'] = $this->parameters;
    $_SESSION['last_results'] = $this->last_result_set;
  }
  
  private function AddToCart()
  {
    global $_SESSION;
    
    $this->obs_table->ProcessActions();
    $selected_ids = $this->obs_table->GetSelectedIDs();
      
    $cart_ids = Array();
    foreach( $this->cart_contents as $next_cart_item )
      $cart_ids[] = $next_cart_item->GetFileID();
      
    foreach( $this->last_result_set as $next_result )
    {
      $next_id = $next_result->GetFileID();
      if( in_array( $next_id, $selected_ids ) &&
	  !in_array( $next_id, $cart_ids ) )
      {
	$this->cart_contents[] = $next_result;
      }
    }
    $_SESSION['cart_contents'] = $this->cart_contents;
  }
  
  private function ViewProfiles( )
  {
  }
  
  private function ViewProfilesAndCals()
  {
  }
  
  private function AdjustDateRange()
  {
    $user_data = new UserData();
    
    $auth_type = $user_data->GetAuthType();
    if( $auth_type == 'anonymous' )
    {
      // get the mjd for now
	  
      $now_date = new Date();
      $now_date->FromDMYString( date( 'd/m/Y' ) );
      $now_mjd = new MJD();
      $now_mjd->FromDate( $now_date );
	  
       // get the mjd the user has chosen as their to value
	   
      $user_date_range = $this->parameters->GetDateRange();
      $user_to_date = $user_date_range->GetToDate();
      $user_to_mjd = new MJD();
      $user_to_mjd->FromDate( $user_to_date );
      
      // if the user has selected a higher mjd
      //   correct it
      //   save it back to the search parameters
      if( $user_to_mjd->ToString() > $now_mjd->ToString() - 547 )
      {
	$user_to_mjd->FromString( $user_to_mjd->ToString() - 547 );
	$user_to_date = $user_to_mjd->ToDate();
	
	$user_date_range->SetToDate( $user_to_date );
	
	$this->date_range_adjusted = true;
      }
      
      
      
      
      
      
      
      
      

//       

//       $chosen_mjd_value = $chosen_mjd->ToString();
//       
//       if( $chosen_mjd_value > $user_to_mjd_value )
//       {
// 	$new_max_mjd = new MJD();
// 	$new_max_mjd->FromString( $user_max_mjd );
// 
// 	$new_date_range = new DateRange();
// 	$new_date_range->SetFromDate( $current_range->GetFromDate() );
// 	$new_date_range->SetToDate( $new_max_mjd->ToDate() );
//       }
    }
  }
};

?>