<?php 


/**
 * (c) David Smith 2008 ATNF CSIRO
 * nopeer@gmail.com
 **/




require_once GREEN_ZONE_DIR . 'Utils/StringUtils.php';




class GZ_BaseForm
{
  var $gz;



  /**
   * Constructor
   *
   *   DOES     - stores the pointer to the green zone
   *   RECEIVES - A green zone
   *   RETURNS  - Nothing
   *   THROWS   - Nothing
   **/

  function __construct( $set_gz )
  {
    $this->gz = $set_gz;
  }



  /**
   * Display
   *
   *    DOES     - Nothing
   *    RECEIVES - Nothing
   *    RETURNS  - An empty string
   *    THROWS   - Nothing
   **/
  
  function Display()
  {
    return '';
  }



  /**
   * Read in form data and alter state, but don't respond to any RealAction commands
   *
   *   DOES     - Nothing
   *   RECEIVES - Nothing
   *   RETURNS  - An empty string
   *   THROWS   - Nothing
   **/

  function ReadForm()
  {
  }
  
  /**
   * Process any RealAction events, and return the name of a new form if applicable
   *
   *   DOES     - Nothing
   *   RECEIVES - Nothing
   *   RETURNS  - An empty string
   *   THROWS   - Nothing
   **/
  
  function ProcessActions()
  {
    return '';
  }



  /**
   * ActionIs
   *
   *   DOES     - Returns true if the action post variable begins with the action string given
   *   RECEIVES - The string to check against
   *   RETURNS  - True if th eaction matches, false otherwise
   *   THROWS   - Nothing
   *   TODO     - Nothing
   **/

  function ActionIs( $action_string )
  {
    $matches = false;

    foreach( Array( $this->gz->_POST, $this->gz->_GET ) as $cmd_source )
    {
      if( isset( $cmd_source['RealAction'] ) )
      {
	if( StartsWith( $cmd_source['RealAction'], $action_string ) )
	{
	  $matches = true;
	}
      }
    }

    return $matches;
  }



  /**
   * GetActionData
   *
   *   DOES     - Get anything in the action post variable after the action command, usually an id
   *   RECEIVES - Nothing
   *   RETURNS  - Any data out of the action post variable after the first space
   *   THROWS   - An exception if the action psot variable is not set
   *   TODO     - Nothing
   **/

  function GetActionData( )
  {
    if( isset( $this->gz->_POST['RealAction'] ) )
    {
      return AdvanceStringTo( $this->gz->_POST['RealAction'], '_' );
    }
    if( isset( $this->gz->_GET['RealAction'] ) )
    {
      return AdvanceStringTo( $this->gz->_GET['RealAction'], '_' );
    }
    throw( new GZ_Exception( 'No Action Set', 'GetActionData' ) );
  }




  /**
   * CheckPostString
   *
   *   DOES     - Retreives a string from post data
   *   RECEIVES - The variable name
   *   RETURNS  - Returns the post variable or false if unset, empty string, or not string
   *   THROWS   - Nothing
   *   TODO     - Nothing
   **/

  function GetPostString( $target_var )
  {
    if( !isset( $this->gz->_POST[$target_var] ) )
      {
	return false;
      }
    else if( '' == $this->gz->_POST[$target_var] )
      {
	return false;
      }
    else if( !is_string( $this->gz->_POST[$target_var] ) )
      {
	return false;
      }
    else
      {
	return $this->gz->_POST[$target_var];
      }
  }



  /**
   * GetPostNum
   *
   *   DOES     - Retreives a number from post data
   *   RECEIVES - The variable name
   *   RETURNS  - Returns the post variable or false if unset or not a number
   *   THROWS   - Nothing
   *   TODO     - Nothing
   **/

  function GetPostNum( $target_var )
  {
    if( !isset( $this->gz->_POST[$target_var] ) )
      {
	return false;
      }
    else if( !is_numeric( $this->gz->_POST[$target_var] ) )
      {
	return false;
      }
    else
      {
	return $this->gz->_POST[$target_var];
      }
  }



  /**
   * GetPostArray
   *
   *   DOES     - Retreives an array from post data, or throws an exception if unset or not an array
   *   RECEIVES - The variable name
   *   RETURNS  - Returns the post variable
   *   THROWS   - A CybergamingException if the variable is unset or not an array
   *   TODO     - Nothing
   **/

  function GetPostArray( $target_var )
  {
    if( !isset( $this->gz->_POST[$target_var] ) )
      {
	throw( new GZ_Exception( 'Variable ' . $target_var . ' not set', 'GZ_BaseForm::GetPostArray' ) ); 
      }
    else if( !is_array( $this->gz->_POST[$target_var] ) )
      {
	throw( new GZ_Exception( 'Variable ' . $target_var . ' should be an array', 'GZ_BaseForm::GetPostArray' ) );
      }
    else
      {
	return $this->gz->_POST[$target_var];
      }
  }
};








?>
