<?php 

/**
 * Written by David Smith
 * nopeer@gmail.com
 *
 * I have found these string functions to be generally usefull.
 **/




/**
 * This function advances the string to just after the target string given.
 **/

function AdvanceStringTo( $source_string, $target_string )
{
  if( strpos( $source_string, $target_string ) === FALSE )
    return FALSE;
  else
    return substr( $source_string, strpos( $source_string, $target_string ) + strlen( $target_string ) );
}



/**
 * This function returns the contents of the source string between the next occurance of the
 * two tags given. If advance is set to true, the advance the string to after the second tag.
 **/

function NextStringBetween( &$source_string, $first_tag, $second_tag, $advance = FALSE )
{
  $start_pos = strpos( $source_string, $first_tag );
  if( $start_pos === FALSE )
    return FALSE;
  
  $start_pos += strlen( $first_tag );
  $end_pos = strpos( $source_string, $second_tag, $start_pos );
  if( $end_pos === FALSE )
    return FALSE;

  $result = substr( $source_string, $start_pos, $end_pos - $start_pos );

  if( $result !== FALSE && $advance )
    {
      $full_tag = $first_tag . $result . $second_tag;
      $source_string = substr( $source_string, strpos( $source_string, $full_tag ) + strlen( $full_tag ) );
    }

  return $result;
}





/**
 * This function returns the substring of the string given up to
 * the start of the second string given. If the second string is
 * not within the first, it will return the entire string.
 **/

function GetStringUpTo( $source, $delimiter )
{
  $length = strpos( $source, $delimiter );
  if( $length === FALSE )
    $length = strlen( $source );

  return substr( $source, 0, $length );
}



/**
 * StartsWith
 *
 *    DOES     - tells you if the first string starts with the second
 *    RECEIVES - a source and search string
 *    RETURNS  - true if the first string starts with the second string
 *    THROWS   - Nothing
 **/

function StartsWith( $source, $search )
{
  if( substr( $source, 0, strlen( $search ) ) == $search )
    {
      return true;
    }

  return false;
}




/**
 * MakeCurrency
 *
 * DOES		- converts a string to have 2 decinal places.
 **/

function MakeCurrency( &$src_string )
{
  if( is_numeric( $src_string ) )
  {
	  $src_string = '$' . number_format( $src_string, 2 );
  }
}




 /**
 * @brief     Add a string to a filename before its extension
 * @example e AddPreExtension( "testing.txt", "_this" ) will return "testing_this.txt"
 * @example f AddPreExtension( "testing", "_this" ) will return "testing_this"
 * @example g AddPreExtension( "can.we.test.txt", "_this" ) will return "can.we.test_this.txt"
 **/

function AddPreExtension( $str, $pre_ext )
{
  $result = $str . $pre_ext;

  if( strpos( $str, '.' ) !== false )
  {
    $last_dot = strrpos( $str, '.' );
    $result = substr( $str, 0, $last_dot - 1);
    $ext = substr( $str, $last_dot );

    $result .= $pre_ext;
    $result .= $ext;
  }

  return $result;
}


/**
  * remove extra whitespace, if we have more than one consecutive delimiter
  * character, then reduce it to 1.
  *
  *  note we are not in a run of delim characters
  *  for each character in the line
  *    if this is a delim character
  *      if we are not in a run
  *        note that we are now in a run
  *        put the character in the output line
  *    otherwise
  *      put the character in the output line
  *      note that we are no longer in a run
  **/
function eatwhite( $line, $delim = ' ' )
{
  $out = '';
  $run = false;
  for( $i = 0; $i < strlen($line); $i ++ )
  {
    if( $line[$i] == $delim )
    {
      if( !$run )
      {
	$run = true;
	$out .= $delim;
      }
    }
    else
    {
      $run = false;
      $out .= $line[$i];
    }
  }
  return $out;
}

/**
  * Get the nth word from a line of text, words are delimited by delim
  * default is space.
  *
  *  set the position of the current word to 0
  *  count from zero to n-1
  *    set the position of the current word to the next delimiter + 1
  *  if there are no more delimiters after the current word
  *    return from the current word to the end of string
  *  otherwise
  *    return from the current word to the next delimiter - 1
  **/

function strword( $line, $n, $delim = ' ' )
{
  $current = 0;
  for( $i = 0; $i < $n; $i ++ )
    $current = strpos( $line, $delim, $current ) + 1;

  $next = strpos( $line, $delim, $current );
  if( $next === false )
    return substr( $line, $current );
  else
  {
    return substr( $line, $current, $next - $current );
  }
}

?>
